## Swiss banknotes

### Input x

6 banknote measurements (continuous covariates):

1. Length
2. Left
3. Right
4. Bottom
5. Top
6. Diagonal

### Output y

Banknote genuineness (categorical variable with 2 levels).

| Value | Genuineness |
| ----- | ----------- |
| 0     | Genuine     |
| 1     | Counterfeit |

### Number of samples

100 banknotes, of which 50 are genuine and 50 are counterfeit.

### References

- Flury, Bernhard. *Multivariate statistics: a practical approach*. Chapman & Hall, Ltd., 1988.
